
#===========================================================
#            Copyright (C) 2023-present AyiinXd
#===========================================================
#||                                                       ||
#||              _         _ _      __  __   _            ||
#||             /   _   _(_|_)_ __  / /__| |           ||
#||            / _ | | | | | | '_     _  | |           ||
#||           / ___  |_| | | | | | |/   (_| |           ||
#||          /_/   ___, |_|_|_| |_/_/___,_|           ||
#||                  |___/                                ||
#||                                                       ||
#===========================================================
# Appreciating the work of others is not detrimental to you
#===========================================================
#

from io import BytesIO
from typing import Any, Union, List, Optional

from typegram.api import ayiin, functions
from typegram.api.object import Object
from typegram.api.utils import Int, Long, Int128, Int256, Bool, Bytes, String, Double, Vector



class TogglePinned(Object):  # type: ignore
    """Telegram API function.

    Details:
        - Layer: ``181``
        - ID: ``9A75A1EF``

peer (:obj:`InputPeer<typegram.api.ayiin.InputPeer>`):
                    N/A
                
        id (List of ``int`` ``32-bit``):
                    N/A
                
        pinned (``bool``):
                    N/A
                
    Returns:
        List of ``int`` ``32-bit``
    """

    __slots__: List[str] = ["peer", "id", "pinned"]

    ID = 0x9a75a1ef
    QUALNAME = "functions.functions.Vector<int>"

    def __init__(self, *, peer: "ayiin.InputPeer", id: List[int], pinned: bool) -> None:
        
                self.peer = peer  # InputPeer
        
                self.id = id  # int
        
                self.pinned = pinned  # Bool

    @staticmethod
    def read(b: BytesIO, *args: Any) -> "TogglePinned":
        # No flags
        
        peer = Object.read(b)
        
        id = Object.read(b, Int)
        
        pinned = Bool.read(b)
        
        return TogglePinned(peer=peer, id=id, pinned=pinned)

    def write(self, *args) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        # No flags
        
        b.write(self.peer.write())
        
        b.write(Vector(self.id, Int))
        
        b.write(Bool(self.pinned))
        
        return b.getvalue()